@@ -1,6 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML;
 our $AUTHORITY = 'cpan:JANDREW';
-use version 0.77; our $VERSION = version->declare('v0.42.2');
+use version 0.77; our $VERSION = version->declare('v0.44.4');
 ###LogSD	warn "You uncovered internal logging statements for Spreadsheet::XLSX::Reader::LibXML-$VERSION";
 
 use 5.010;
@@ -1330,17 +1330,16 @@ The following uses the 'TestBook.xlsx' file found in the t/test_files/ folder of
 	
 =head1 DEPRECATION
 
-I<his module is being replaced by L<Spreadsheet::Reader::ExcelXML>.  The L<bugs associated
-|http://www.perlmonks.org/?node_id=1151609> with L<XML::LibXML> wound up being insurmountable.  
-I can only infer for all cases but release v0.38.22 will not build on one of my windows machines 
-and on an AWS server used at $work.  Netbsd doesn't have a single build since release.  I still 
-can't distil the failure mode down to a case that I can submit but the new package with L<XML::LibXML> 
-is running where this one didn't.  I opened the package in PAUSE to co-maintainership and I would 
-not be concerned if someone wanted to take this over but for now this is an orphan package.  
-I plan on pulling it from CPAN altogether after a while.  The new package does run slower for 
-large files since it uses are pure perl parser.  On the other hand a fair amount of the TODO 
-and bugs for this package got fixed in the new release.  I invite you to try it if you liked 
-this package.>
+I<This module is being replaced by L<Spreadsheet::Reader::ExcelXML>.  The L<bugs associated
+|http://www.perlmonks.org/?node_id=1151609> with L<XML::LibXML> integration wound up being 
+insurmountable for me.  I can only infer for all cases but release v0.38.22 will not build on one of 
+my windows machines and on an AWS server used at $work.  Netbsd doesn't have a single passed test since 
+release.  I still can't even distil the failure mode down to a case that I can submit but the new package 
+without L<XML::LibXML> is running where this one didn't.  I opened the package in PAUSE to co-maintainership 
+and I would be happy to hand full ownership to another party if someone wanted to take this over.  For now 
+this is an orphan package.  I plan on pulling it from CPAN altogether after a year.  The new package does run 
+slower for large files since it uses a pure perl parser.  On the other hand a fair amount of the TODO 
+and bugs for this package got fixed in the new release.  I invite you to try it if you liked this package.>
 
 =head1 DESCRIPTION
 
@@ -2846,6 +2845,8 @@ L<H.Merijin Brand|https://github.com/Tux>
 
 L<Todd Eigenschink|mailto:todd@xymmetrix.com>
 
+L<Alexandr Ciornii|http://chorny.net>
+
 =back
 
 =head1 COPYRIGHT
