@@ -1,6 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML::XMLReader::PositionSharedStrings;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = version->declare('v0.42.2');
+use version; our $VERSION = version->declare('v0.44.4');
 ###LogSD	warn "You uncovered internal logging statements for Spreadsheet::XLSX::Reader::LibXML::XMLReader::PositionSharedStrings-$VERSION";
 
 use 5.010;
@@ -317,30 +317,7 @@ Spreadsheet::XLSX::Reader::LibXML::XMLReader::PositionSharedStrings - Position b
 
 =head1 SYNOPSIS
 
-	#!/usr/bin/env perl
-	use Data::Dumper;
-	use MooseX::ShortCut::BuildInstance qw( build_instance );
-	use Spreadsheet::XLSX::Reader::LibXML::Error;
-	use Spreadsheet::XLSX::Reader::LibXML::XMLReader::SharedStrings;
-
-	my $file_instance = build_instance(
-	    package      => 'SharedStringsInstance',
-	    superclasses => ['Spreadsheet::XLSX::Reader::LibXML::XMLReader::SharedStrings'],
-	    file         => 'sharedStrings.xml',
-	    error_inst   => Spreadsheet::XLSX::Reader::LibXML::Error->new,
-	);
-	print Dumper( $file_instance->get_shared_string_position( 3 ) );
-	print Dumper( $file_instance->get_shared_string_position( 12 ) );
-
-	#######################################
-	# SYNOPSIS Screen Output
-	# 01: $VAR1 = {
-	# 02:     'raw_text' => ' '
-	# 03: };
-	# 04: $VAR1 = {
-	# 05:     'raw_text' => 'Superbowl Audibles'
-	# 06: };
-	#######################################
+	Broken!
     
 =head1 DESCRIPTION
 
